@@ -1,5 +1,5 @@
-#ifndef _PYTHON_BYTE_WRITER_H_0EADA4FC_9BD3_4BC6_875F_54C8C397EDCA
-#define _PYTHON_BYTE_WRITER_H_0EADA4FC_9BD3_4BC6_875F_54C8C397EDCA
+#ifndef PYTHON_BYTE_WRITER_H_0EADA4FC_9BD3_4BC6_875F_54C8C397EDCA
+#define PYTHON_BYTE_WRITER_H_0EADA4FC_9BD3_4BC6_875F_54C8C397EDCA
 
 #include "Python.h"
 #include "IOBasicTypes.h"
